@@ -1,9 +1,8 @@
 from inspect import isawaitable
-from inspect import isawaitable
 from typing import List, Optional, Protocol
 
-from graphene import Context
-from graphql import GraphQLError, GraphQLResolveInfo
+from graphene import Context, ResolveInfo
+from graphql import GraphQLError
 
 
 class Extension(Protocol):
@@ -16,7 +15,7 @@ class Extension(Protocol):
     def request_finished(self, context: Context):
         pass  # pragma: no cover
 
-    async def resolve(self, next_, parent, info: GraphQLResolveInfo, **kwargs):
+    async def resolve(self, next_, parent, info: ResolveInfo, **kwargs):
         result = next_(parent, info, **kwargs)
         if isawaitable(result):
             result = await result
